package com.yaohun.aurechargedata.api;

import com.yaohun.aurechargedata.Main;
import com.yaohun.aurechargedata.data.PlayerData;
import com.yaohun.aurechargedata.manage.ConsumeManage;
import com.yaohun.aurechargedata.util.TimeType;

public abstract class ConsumeAPI {
    public static PlayerData getConsumePlayer(String name){
        ConsumeManage manage = Main.consumeManage;  // 获取消费管理实例
        return manage.getPlayerData(name);  // 获取玩家的消费数据实例
    }
    public static int getConsumeData(String name, TimeType timeType) {
        ConsumeManage manage = Main.consumeManage;  // 获取消费管理实例
        PlayerData dataAPI = manage.getPlayerData(name);  // 获取玩家的消费数据实例
        // 根据时间类型获取玩家的累积消费数据
        switch (timeType) {
            case DAILY:
                return dataAPI.getValueData(TimeType.DAILY);  // 获取每日累积消费数据
            case MONTHLY:
                return dataAPI.getValueData(TimeType.MONTHLY);  // 获取每月累积消费数据
            case ANNUAL:
                return dataAPI.getValueData(TimeType.ANNUAL);  // 获取年度累积消费数据
            default:
                return -1;  // 如果时间类型不匹配，则返回默认值或进行适当处理
        }
    }

    public static void setConsumeData(String name, int money) {
        ConsumeManage manage = Main.consumeManage;  // 获取消费管理实例
        PlayerData dataAPI = manage.getPlayerData(name);  // 获取玩家的消费数据实例
        // 设置玩家的每日、每月和年度消费数据为指定金额
        dataAPI.setValueData(TimeType.DAILY, money);  // 设置每日消费数据
        dataAPI.setValueData(TimeType.MONTHLY, money);  // 设置每月消费数据
        dataAPI.setValueData(TimeType.ANNUAL, money);  // 设置年度消费数据
    }
    // 增加累积消费金额
    public static void addConsumeData(String name, int money) {
        ConsumeManage manage = Main.consumeManage;  // 获取消费管理实例
        PlayerData dataAPI = manage.getPlayerData(name);  // 获取玩家的消费数据实例
        // 向玩家的每日、每月和年度消费数据中添加指定金额
        dataAPI.addValueData(TimeType.DAILY, money);  // 增加每日消费数据
        dataAPI.addValueData(TimeType.MONTHLY, money);  // 增加每月消费数据
        dataAPI.addValueData(TimeType.ANNUAL, money);  // 增加年度消费数据
    }
    public static void takeConsumeData(String name, int money) {
        ConsumeManage manage = Main.consumeManage;  // 获取消费管理实例
        PlayerData dataAPI = manage.getPlayerData(name);  // 获取玩家的消费数据实例
        // 减少玩家的每日、每月和年度消费数据
        int currentDaily = dataAPI.getValueData(TimeType.DAILY);
        if (currentDaily >= money) {
            dataAPI.setValueData(TimeType.DAILY, currentDaily - money);  // 减少每日消费数据
        } else {
            dataAPI.setValueData(TimeType.DAILY, 0);  // 如果减少金额大于当前累积值，设为0
        }
        int currentMonthly = dataAPI.getValueData(TimeType.MONTHLY);
        if (currentMonthly >= money) {
            dataAPI.setValueData(TimeType.MONTHLY, currentMonthly - money);  // 减少每月消费数据
        } else {
            dataAPI.setValueData(TimeType.MONTHLY, 0);  // 如果减少金额大于当前累积值，设为0
        }
        int currentAnnual = dataAPI.getValueData(TimeType.ANNUAL);
        if (currentAnnual >= money) {
            dataAPI.setValueData(TimeType.ANNUAL, currentAnnual - money);  // 减少年度消费数据
        } else {
            dataAPI.setValueData(TimeType.ANNUAL, 0);  // 如果减少金额大于当前累积值，设为0
        }
    }

    // 增加累积消费金额
    public static void addConsumeData(String name,int money,TimeType timeType) {
        ConsumeManage manage = Main.consumeManage;  // 获取消费管理实例
        PlayerData dataAPI = manage.getPlayerData(name);  // 获取玩家的消费数据实例
        // 根据时间类型向玩家的消费数据中添加指定金额
        if (timeType == TimeType.DAILY) {
            dataAPI.addValueData(TimeType.DAILY, money);  // 增加每日消费数据
            dataAPI.addValueData(TimeType.MONTHLY, money);  // 增加每月消费数据
            dataAPI.addValueData(TimeType.ANNUAL, money);  // 增加年度消费数据
        } else if (timeType == TimeType.MONTHLY) {
            dataAPI.addValueData(TimeType.MONTHLY, money);  // 增加每月消费数据
            dataAPI.addValueData(TimeType.ANNUAL, money);  // 增加年度消费数据
        } else if (timeType == TimeType.ANNUAL) {
            dataAPI.addValueData(TimeType.ANNUAL, money);  // 增加年度消费数据
        }
    }

    public void setConsumeData(String name, int money, TimeType timeType) {
        ConsumeManage manage = Main.consumeManage;  // 获取消费管理实例
        PlayerData dataAPI = manage.getPlayerData(name);  // 获取玩家的消费数据实例
        // 根据时间类型设置玩家的累积消费数据
        if (timeType == TimeType.DAILY) {
            dataAPI.setValueData(TimeType.DAILY, money);  // 设置每日累积消费数据
            dataAPI.setValueData(TimeType.MONTHLY, money);  // 设置每月累积消费数据
            dataAPI.setValueData(TimeType.ANNUAL, money);  // 设置年度累积消费数据
        } else if (timeType == TimeType.MONTHLY) {
            dataAPI.setValueData(TimeType.MONTHLY, money);  // 设置每月累积消费数据
            dataAPI.setValueData(TimeType.ANNUAL, money);  // 设置年度累积消费数据
        } else if (timeType == TimeType.ANNUAL) {
            dataAPI.setValueData(TimeType.ANNUAL, money);  // 设置年度累积消费数据
        }
    }

    public void takeConsumeData(String name, int money, TimeType timeType) {
        ConsumeManage manage = Main.consumeManage;  // 获取消费管理实例
        PlayerData dataAPI = manage.getPlayerData(name);  // 获取玩家的消费数据实例
        // 根据时间类型减少玩家的累积消费数据
        if (timeType == TimeType.DAILY) {
            int currentDaily = dataAPI.getValueData(TimeType.DAILY);
            if (currentDaily >= money) {
                dataAPI.setValueData(TimeType.DAILY, currentDaily - money);  // 减少每日累积消费数据
            } else {
                dataAPI.setValueData(TimeType.DAILY, 0);  // 如果减少金额大于当前累积值，设为0
            }
            int currentMonthly = dataAPI.getValueData(TimeType.MONTHLY);
            if (currentMonthly >= money) {
                dataAPI.setValueData(TimeType.MONTHLY, currentMonthly - money);  // 减少每月累积消费数据
            } else {
                dataAPI.setValueData(TimeType.MONTHLY, 0);  // 如果减少金额大于当前累积值，设为0
            }
            int currentAnnual = dataAPI.getValueData(TimeType.ANNUAL);
            if (currentAnnual >= money) {
                dataAPI.setValueData(TimeType.ANNUAL, currentAnnual - money);  // 减少年度累积消费数据
            } else {
                dataAPI.setValueData(TimeType.ANNUAL, 0);  // 如果减少金额大于当前累积值，设为0
            }
        } else if (timeType == TimeType.MONTHLY) {
            int currentMonthly = dataAPI.getValueData(TimeType.MONTHLY);
            if (currentMonthly >= money) {
                dataAPI.setValueData(TimeType.MONTHLY, currentMonthly - money);  // 减少每月累积消费数据
            } else {
                dataAPI.setValueData(TimeType.MONTHLY, 0);  // 如果减少金额大于当前累积值，设为0
            }
            int currentAnnual = dataAPI.getValueData(TimeType.ANNUAL);
            if (currentAnnual >= money) {
                dataAPI.setValueData(TimeType.ANNUAL, currentAnnual - money);  // 减少年度累积消费数据
            } else {
                dataAPI.setValueData(TimeType.ANNUAL, 0);  // 如果减少金额大于当前累积值，设为0
            }
        } else if (timeType == TimeType.ANNUAL) {
            int currentAnnual = dataAPI.getValueData(TimeType.ANNUAL);
            if (currentAnnual >= money) {
                dataAPI.setValueData(TimeType.ANNUAL, currentAnnual - money);  // 减少年度累积消费数据
            } else {
                dataAPI.setValueData(TimeType.ANNUAL, 0);  // 如果减少金额大于当前累积值，设为0
            }
        }
    }
}
